Package: shinydashboard
Title: Create Dashboards with 'Shiny'
Version: 0.7.3
Authors@R: c(
    person("Winston", "Chang", , "winston@posit.co", role = c("aut", "cre")),
    person("Barbara", "Borges Ribeiro", role = "aut"),
    person(, "Posit Software, PBC", role = "cph"),
    person(, "Almasaeed Studio", role = c("ctb", "cph"),
           comment = "AdminLTE theme for Bootstrap"),
    person(, "Adobe Systems Incorporated", role = c("ctb", "cph"),
           comment = "Source Sans Pro font")
  )
Description: Create dashboards with 'Shiny'. This package provides a theme
    on top of 'Shiny', making it easy to create attractive dashboards.
License: MIT + file LICENSE
URL: https://rstudio.github.io/shinydashboard/,
        https://github.com/rstudio/shinydashboard
BugReports: https://github.com/rstudio/shinydashboard/issues
Depends: R (>= 3.0)
Imports: htmltools (>= 0.2.6), promises, shiny (>= 1.0.0), utils
Encoding: UTF-8
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-04-21 16:14:20 UTC; garrick
Author: Winston Chang [aut, cre],
  Barbara Borges Ribeiro [aut],
  Posit Software, PBC [cph],
  Almasaeed Studio [ctb, cph] (AdminLTE theme for Bootstrap),
  Adobe Systems Incorporated [ctb, cph] (Source Sans Pro font)
Maintainer: Winston Chang <winston@posit.co>
Repository: CRAN
Date/Publication: 2025-04-21 21:30:02 UTC
Built: R 4.6.0; ; 2026-04-26 11:13:02 UTC; unix
