% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/shinydashboard-package.r
\docType{package}
\name{shinydashboard}
\alias{shinydashboard}
\alias{shinydashboard-package}
\title{shinydashboard}
\description{
shinydashboard
}
